<?php
/**
 * Copyright © 2015 FiloBlu . All rights reserved.
 */
namespace FiloBlu\Flow\Helper;

/**
 * Class Stock
 * @package FiloBlu\Flow\Helper
 */
class Stock extends \Magento\Framework\App\Helper\AbstractHelper
{
    /**
     * @var \Magento\Framework\App\ResourceConnection
     */
	protected $connection;

    /**
     * Stock constructor.
     * @param \Magento\Framework\App\Helper\Context $context
     * @param \Magento\Framework\App\ResourceConnection $connection
     */
	public function __construct(\Magento\Framework\App\Helper\Context $context,
								\Magento\Framework\App\ResourceConnection $connection)
	{
		$this->connection=$connection;
		parent::__construct($context);
	}

	/**
	 * Adjust $qty_to_update taking into account sold products that are in configured status.
	 */
	public function getRealQty($product_id,$qty_to_update) {

		if (!$product_id) {
            throw new \Exception('product_id error in getRealQty');
        }

		if ($qty_to_update == 0) {
            return 0;
        }

		$reservedQty = $this->getReservedQty($product_id);

		if (!$reservedQty) {
            return $qty_to_update;
        }

		$qty_refreshed = $qty_to_update - $reservedQty;

		return ($qty_refreshed > 0) ? $qty_refreshed : 0;
	}

    //FOS-720
    public function getReservedQtyOrderList($product_id){

        $order_list = array();

        $readConnection = $this->connection->getConnection(\Magento\Framework\App\ResourceConnection::DEFAULT_CONNECTION);

        $order_statuses = $this->scopeConfig->getValue('filoblu_flow/flow_stock_option/flow_reserved_order_statuses') ;

        if (!$order_statuses) {
            return "";
        }

        $order_statuses =  implode("','", explode(',',$order_statuses));

        $query = $readConnection->select()
            ->from(array("soi" => "sales_order_item"), array('soi.product_id','soi.sku','soi.order_id','soi.qty_ordered'))
            ->join(array("cpe" => "catalog_product_entity"), 'cpe.entity_id = soi.product_id', array())
            ->join(array("so" => "sales_order"), 'soi.order_id = so.entity_id', array('so.increment_id'))
            ->where("status IN ('".$order_statuses."') AND soi.product_id = $product_id");
        $results = $readConnection->fetchAssoc($query);

        if(count($results) > 0){

            foreach ($results as $result) {
                $order_list[] = $result['increment_id'];
            }

        } else {

            return "";

        }

        $order_list = array_unique($order_list);
        $order_list_string = implode(",",$order_list);

        return $order_list_string;
    }

    /**
     * @param $product_id
     * @return int
     */
	public function getReservedQty($product_id) {

		$order_statuses = $this->scopeConfig->getValue('filoblu_flow/flow_stock_option/flow_reserved_order_statuses') ;

		if (!$order_statuses) {
            return 0;
        }

		$readConnection = $this->connection->getConnection(\Magento\Framework\App\ResourceConnection::DEFAULT_CONNECTION);

		$order_statuses =  implode("','", explode(',',$order_statuses));

		$query = $readConnection->select()
			->from(array("soi" => "sales_order_item"), array('SUM(soi.qty_ordered) as qty'))
			->join(array("cpe" => "catalog_product_entity"), 'cpe.entity_id = soi.product_id', array())
			->join(array("so" => "sales_order"), 'soi.order_id = so.entity_id', array())
			->where("status IN ('".$order_statuses."') AND soi.product_id = $product_id")
			->group('soi.product_id');

		$results = $readConnection->fetchOne($query);

		if (!$results){
			return 0;
		}

		return (int) $results;
	}

}


